@@ -16,8 +16,12 @@
 
 package org.drools.workbench.screens.scenariosimulation.service;
 
+import java.util.Map;
+
+import org.drools.workbench.screens.scenariosimulation.model.Scenario;
 import org.drools.workbench.screens.scenariosimulation.model.ScenarioSimulationModel;
 import org.drools.workbench.screens.scenariosimulation.model.ScenarioSimulationModelContent;
+import org.drools.workbench.screens.scenariosimulation.model.SimulationDescriptor;
 import org.guvnor.common.services.shared.metadata.model.Metadata;
 import org.jboss.errai.bus.server.annotations.Remote;
 import org.uberfire.backend.vfs.Path;
@@ -38,5 +42,14 @@ public interface ScenarioSimulationService
 
     ScenarioSimulationModelContent loadContent(final Path path);
 
-    ScenarioSimulationModel runScenario(final Path path, final ScenarioSimulationModel model);
+    Map<Integer, Scenario> runScenario(Path path,
+                                       SimulationDescriptor simulationDescriptor,
+                                       Map<Integer, Scenario> scenarioMap);
+
+    Path create(final Path context,
+                final String fileName,
+                final ScenarioSimulationModel content,
+                final String comment,
+                final ScenarioSimulationModel.Type type,
+                final String value);
 }
