@@ -18,48 +18,36 @@ package org.drools.workbench.screens.scenariosimulation.backend.server;
 
 import java.util.ArrayList;
 import java.util.List;
-import java.util.function.BiFunction;
+import java.util.Map;
 
 import javax.enterprise.context.ApplicationScoped;
 import javax.enterprise.event.Event;
 import javax.inject.Inject;
 
 import org.drools.workbench.screens.scenariosimulation.backend.server.runner.AbstractScenarioRunner;
-import org.drools.workbench.screens.scenariosimulation.backend.server.runner.ScenarioRunnerImpl;
-import org.drools.workbench.screens.scenariosimulation.model.ScenarioSimulationModel;
-import org.drools.workbench.screens.scenariosimulation.model.Simulation;
+import org.drools.workbench.screens.scenariosimulation.backend.server.runner.ScenarioRunnerProvider;
+import org.drools.workbench.screens.scenariosimulation.model.Scenario;
+import org.drools.workbench.screens.scenariosimulation.model.SimulationDescriptor;
 import org.drools.workbench.screens.scenariosimulation.service.ScenarioRunnerService;
 import org.guvnor.common.services.shared.test.Failure;
 import org.guvnor.common.services.shared.test.TestResultMessage;
 import org.jboss.errai.bus.server.annotations.Service;
 import org.junit.runner.Result;
+import org.junit.runner.Runner;
 import org.kie.api.runtime.KieContainer;
-import org.kie.workbench.common.services.backend.builder.service.BuildInfoService;
-import org.kie.workbench.common.services.backend.project.ModuleClassLoaderHelper;
-import org.kie.workbench.common.services.shared.project.KieModule;
-import org.kie.workbench.common.services.shared.project.KieModuleService;
 import org.uberfire.backend.vfs.Path;
 
 import static org.drools.workbench.screens.scenariosimulation.backend.server.util.JunitRunnerHelper.runWithJunit;
 
 @Service
 @ApplicationScoped
-public class ScenarioRunnerServiceImpl
+public class ScenarioRunnerServiceImpl extends AbstractKieContainerService
         implements ScenarioRunnerService {
 
     @Inject
     private Event<TestResultMessage> defaultTestResultMessageEvent;
 
-    @Inject
-    private KieModuleService moduleService;
-
-    @Inject
-    private BuildInfoService buildInfoService;
-
-    @Inject
-    private ModuleClassLoaderHelper classLoaderHelper;
-
-    private BiFunction<KieContainer, Simulation, AbstractScenarioRunner> runnerSupplier = ScenarioRunnerImpl::new;
+    private ScenarioRunnerProvider runnerSupplier = null;
 
     @Override
     public void runAllTests(final String identifier,
@@ -87,16 +75,13 @@ public class ScenarioRunnerServiceImpl
     }
 
     @Override
-    public void runTest(final String identifier,
-                        final Path path,
-                        final ScenarioSimulationModel model) {
-
-        KieModule kieModule = getKieModule(path);
-        ClassLoader moduleClassLoader = classLoaderHelper.getModuleClassLoader(kieModule);
-        KieContainer kieContainer = getKieContainer(kieModule);
-        AbstractScenarioRunner scenarioRunner = getRunnerSupplier().apply(kieContainer, model.getSimulation());
-
-        scenarioRunner.setClassLoader(moduleClassLoader);
+    public Map<Integer, Scenario> runTest(final String identifier,
+                                          final Path path,
+                                          final SimulationDescriptor simulationDescriptor,
+                                          final Map<Integer, Scenario> scenarioMap) {
+        KieContainer kieContainer = getKieContainer(path);
+        Runner scenarioRunner = getOrCreateRunnerSupplier(simulationDescriptor)
+                .create(kieContainer, simulationDescriptor, scenarioMap);
 
         final List<Failure> failures = new ArrayList<>();
 
@@ -110,21 +95,18 @@ public class ScenarioRunnerServiceImpl
                         result.getRunCount(),
                         result.getRunTime(),
                         failures));
+
+        return scenarioMap;
     }
 
-    protected KieModule getKieModule(Path path) {
-        return moduleService.resolveModule(path);
+    public ScenarioRunnerProvider getOrCreateRunnerSupplier(SimulationDescriptor simulationDescriptor) {
+        if (runnerSupplier != null) {
+            return runnerSupplier;
+        }
+        return AbstractScenarioRunner.getSpecificRunnerProvider(simulationDescriptor);
     }
 
-    protected KieContainer getKieContainer(KieModule kieModule) {
-        return buildInfoService.getBuildInfo(kieModule).getKieContainer();
-    }
-
-    public BiFunction<KieContainer, Simulation, AbstractScenarioRunner> getRunnerSupplier() {
-        return runnerSupplier;
-    }
-
-    public void setRunnerSupplier(BiFunction<KieContainer, Simulation, AbstractScenarioRunner> runnerSupplier) {
+    public void setRunnerSupplier(ScenarioRunnerProvider runnerSupplier) {
         this.runnerSupplier = runnerSupplier;
     }
 }
