@@ -16,6 +16,7 @@
 package org.drools.workbench.screens.scenariosimulation.client.rightpanel;
 
 import java.util.HashMap;
+import java.util.List;
 import java.util.Map;
 import java.util.concurrent.atomic.AtomicBoolean;
 
@@ -61,25 +62,39 @@ public class ListGroupItemPresenter implements ListGroupItemView.Presenter {
     }
 
     @Override
-    public void selectProperty(String factName, String propertyName) {
+    public void showAll() {
+        fieldItemPresenter.showAll();
+    }
+
+    @Override
+    public void selectProperty(String factName, List<String> propertyParts) {
         final ListGroupItemView listGroupItemView = listGroupItemViewMap.get(factName);
         if (!listGroupItemView.isShown()) {
             onToggleRowExpansion(listGroupItemView, false);
         }
         String key;
-        if (propertyName.contains(".")) {
-            key = factName + "." + propertyName.substring(0, propertyName.indexOf("."));
+        for (int i = 1; i < propertyParts.size(); i++) {
+            String subPart = String.join(".", propertyParts.subList(0, i));
+            key = factName + "." + subPart;
             final ListGroupItemView subListGroupItemView = listGroupItemViewMap.get(key);
-            if (!subListGroupItemView.isShown()) {
+            if (subListGroupItemView != null && !subListGroupItemView.isShown()) {
                 onToggleRowExpansion(subListGroupItemView, false);
             }
         }
-        key = factName + "." + propertyName;
+        key = factName + "." + String.join(".", propertyParts);
         if (fieldItemPresenter.fieldItemMap.containsKey(key)) {
             fieldItemPresenter.fieldItemMap.get(key).onFieldElementClick();
         }
     }
 
+    @Override
+    public void hideProperty(String factName, List<String> propertyParts) {
+        String key = factName + "." + String.join(".", propertyParts);
+        if (fieldItemPresenter.fieldItemMap.containsKey(key)) {
+            fieldItemPresenter.fieldItemMap.get(key).hide();
+        }
+    }
+
     @Override
     public void disable() {
         this.disabled.set(true);
@@ -97,25 +112,16 @@ public class ListGroupItemPresenter implements ListGroupItemView.Presenter {
 
     @Override
     public DivElement getDivElement(String factName, FactModelTree factModelTree) {
-        if (listGroupItemViewMap.containsKey(factName)) {
-            return listGroupItemViewMap.get(factName).getListGroupItem();
-        } else {
-            final ListGroupItemView listGroupItemView = commonGetListGroupItemView("", factName, false);
-            populateListGroupItemView(listGroupItemView, "", factName, factModelTree);
-            return listGroupItemView.getListGroupItem();
-        }
+        final ListGroupItemView listGroupItemView = commonGetListGroupItemView("", factName, false);
+        populateListGroupItemView(listGroupItemView, "", factName, factModelTree);
+        return listGroupItemView.getListGroupItem();
     }
 
     @Override
     public DivElement getDivElement(String fullPath, String factName, String factModelTreeClass) {
-        String key = fullPath.isEmpty() ? factName : fullPath + "." + factName;
-        if (listGroupItemViewMap.containsKey(key)) {
-            return listGroupItemViewMap.get(key).getListGroupItem();
-        } else {
-            final ListGroupItemView listGroupItemView = commonGetListGroupItemView(fullPath, factName, true);
-            populateListGroupItemView(listGroupItemView, factName, factModelTreeClass);
-            return listGroupItemView.getListGroupExpansion();
-        }
+        final ListGroupItemView listGroupItemView = commonGetListGroupItemView(fullPath, factName, true);
+        populateListGroupItemView(listGroupItemView, factName, factModelTreeClass);
+        return listGroupItemView.getListGroupExpansion();
     }
 
     @Override
@@ -129,7 +135,7 @@ public class ListGroupItemPresenter implements ListGroupItemView.Presenter {
             if (listGroupItemView.isToExpand()) {
                 FactModelTree factModelTree =
                         rightPanelPresenter.getFactModelTreeFromFactTypeMap(listGroupItemView.getFactType())
-                                .orElse(rightPanelPresenter.getFactModelTreeFromHiddenMap(listGroupItemView.getFactType()));
+                                .orElseGet(() -> rightPanelPresenter.getFactModelTreeFromHiddenMap(listGroupItemView.getFactType()));
                 if (factModelTree != null) {
                     populateListGroupItemView(listGroupItemView, listGroupItemView.getParentPath(), listGroupItemView.getFactName(), factModelTree);
                     listGroupItemView.setToExpand(false);
