@@ -16,8 +16,15 @@
 
 package org.drools.workbench.screens.scenariosimulation.client.editor;
 
+import java.util.AbstractMap;
+import java.util.Collections;
+import java.util.HashSet;
+import java.util.Map;
+import java.util.Set;
+
 import com.google.gwtmockito.GwtMockitoTestRunner;
 import org.drools.workbench.screens.scenariosimulation.client.commands.ScenarioSimulationContext;
+import org.drools.workbench.screens.scenariosimulation.client.editor.strategies.DataManagementStrategy;
 import org.drools.workbench.screens.scenariosimulation.client.events.RedoEvent;
 import org.drools.workbench.screens.scenariosimulation.client.events.UndoEvent;
 import org.drools.workbench.screens.scenariosimulation.client.handlers.ScenarioSimulationDocksHandler;
@@ -27,7 +34,7 @@ import org.drools.workbench.screens.scenariosimulation.client.rightpanel.RightPa
 import org.drools.workbench.screens.scenariosimulation.client.type.ScenarioSimulationResourceType;
 import org.drools.workbench.screens.scenariosimulation.client.widgets.ScenarioGrid;
 import org.drools.workbench.screens.scenariosimulation.client.widgets.ScenarioGridLayer;
-import org.drools.workbench.screens.scenariosimulation.client.widgets.ScenarioGridPanel;
+import org.drools.workbench.screens.scenariosimulation.model.Scenario;
 import org.drools.workbench.screens.scenariosimulation.model.ScenarioSimulationModel;
 import org.drools.workbench.screens.scenariosimulation.model.ScenarioSimulationModelContent;
 import org.guvnor.common.services.shared.metadata.model.Overview;
@@ -58,8 +65,10 @@ import org.uberfire.mvp.impl.PathPlaceRequest;
 import org.uberfire.workbench.events.NotificationEvent;
 import org.uberfire.workbench.model.menu.MenuItem;
 
+import static junit.framework.TestCase.assertTrue;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertFalse;
+import static org.mockito.Matchers.anyInt;
 import static org.mockito.Matchers.eq;
 import static org.mockito.Matchers.isA;
 import static org.mockito.Mockito.any;
@@ -75,7 +84,6 @@ import static org.mockito.Mockito.when;
 @RunWith(GwtMockitoTestRunner.class)
 public class ScenarioSimulationEditorPresenterTest extends AbstractScenarioSimulationEditorTest {
 
-
     private ScenarioSimulationEditorPresenter presenter;
 
     private ScenarioSimulationEditorPresenter presenterSpy;
@@ -95,8 +103,6 @@ public class ScenarioSimulationEditorPresenterTest extends AbstractScenarioSimul
     @Mock
     private ScenarioGridLayer scenarioGridLayerMock;
     @Mock
-    private ScenarioGridPanel scenarioGridPanelMock;
-    @Mock
     private ScenarioSimulationView scenarioSimulationViewMock;
     @Mock
     private ScenarioGridModel scenarioGridModelMock;
@@ -128,6 +134,8 @@ public class ScenarioSimulationEditorPresenterTest extends AbstractScenarioSimul
     private ScenarioMenuItem undoMenuItemMock;
     @Mock
     private ScenarioMenuItem redoMenuItemMock;
+    @Mock
+    private DataManagementStrategy dataManagementStrategyMock;
 
     @Before
     public void setup() {
@@ -171,6 +179,8 @@ public class ScenarioSimulationEditorPresenterTest extends AbstractScenarioSimul
                 this.packageName = SCENARIO_PACKAGE;
                 this.eventBus = eventBusMock;
                 this.context = contextMock;
+                this.dataManagementStrategy = dataManagementStrategyMock;
+                this.model = scenarioSimulationModelMock;
             }
 
             @Override
@@ -192,13 +202,6 @@ public class ScenarioSimulationEditorPresenterTest extends AbstractScenarioSimul
 
             }
 
-//            @Override
-//            protected void loadContent() {
-//                return new ScenarioSimulationModelContent(model,
-//                                                   new Overview(),
-//                                                   new PackageDataModelOracleBaselinePayload());
-//            }
-
             @Override
             protected String getJsonModel(ScenarioSimulationModel model) {
                 return "";
@@ -217,12 +220,12 @@ public class ScenarioSimulationEditorPresenterTest extends AbstractScenarioSimul
 
         final AsyncPackageDataModelOracle oracle = mock(AsyncPackageDataModelOracle.class);
         when(oracleFactoryMock.makeAsyncPackageDataModelOracle(any(),
-                                                               eq(model),
+                                                               eq(modelLocal),
                                                                eq(content.getDataModel()))).thenReturn(oracle);
         presenter.onStartup(mock(ObservablePath.class),
                             mock(PlaceRequest.class));
         verify(importsWidgetPresenterMock).setContent(oracle,
-                                                      model.getImports(),
+                                                      modelLocal.getImports(),
                                                       false);
         verify(kieViewMock).addImportsTab(importsWidgetPresenterMock);
         verify(scenarioSimulationViewMock).showLoading();
@@ -335,13 +338,27 @@ public class ScenarioSimulationEditorPresenterTest extends AbstractScenarioSimul
 
     @Test
     public void onRunTest() throws Exception {
-        doReturn(new ScenarioSimulationModelContent(model,
+        doReturn(new ScenarioSimulationModelContent(modelLocal,
                                                     new Overview(),
                                                     new PackageDataModelOracleBaselinePayload())).when(scenarioSimulationServiceMock).loadContent(any());
-        when(scenarioSimulationServiceMock.runScenario(any(), any())).thenReturn(mock(ScenarioSimulationModel.class));
-        presenter.onStartup(mock(ObservablePath.class), mock(PlaceRequest.class));
+        when(scenarioSimulationServiceMock.runScenario(any(), any(), any())).thenReturn(scenarioMapMock);
+        when(statusMock.getSimulation()).thenReturn(simulationMock);
+        when(contextMock.getStatus()).thenReturn(statusMock);
+        assertFalse(modelLocal.getSimulation().equals(simulationMock));
+        presenter.onStartup(observablePathMock, placeRequestMock);
         presenter.onRunScenario();
-        verify(scenarioSimulationServiceMock).runScenario(any(), eq(model));
+        verify(scenarioSimulationServiceMock, times(1)).runScenario(any(), any(), any());
+        verify(scenarioGridModelMock, times(1)).resetErrors();
+        verify(scenarioSimulationViewMock, times(1)).refreshContent(any());
+        verify(scenarioSimulationDocksHandlerMock).expandTestResultsDock();
+        assertTrue(modelLocal.getSimulation().equals(simulationMock));
+    }
+
+    @Test
+    public void onRunTestById() throws Exception {
+        when(simulationMock.getScenarioByIndex(anyInt())).thenReturn(mock(Scenario.class));
+        presenter.onRunScenario(Collections.singletonList(0));
+        verify(scenarioSimulationServiceMock, times(1)).runScenario(any(), any(), any());
         verify(scenarioGridModelMock, times(1)).resetErrors();
         verify(scenarioSimulationViewMock, times(1)).refreshContent(any());
         verify(scenarioSimulationDocksHandlerMock).expandTestResultsDock();
@@ -350,10 +367,17 @@ public class ScenarioSimulationEditorPresenterTest extends AbstractScenarioSimul
     @Test
     public void refreshModelContent() {
         when(scenarioSimulationModelMock.getSimulation()).thenReturn(simulationMock);
-        presenter.refreshModelContent(scenarioSimulationModelMock);
+        Set<Map.Entry<Integer, Scenario>> entries = new HashSet<>();
+        int scenarioNumber = 1;
+        int scenarioIndex = scenarioNumber - 1;
+        entries.add(new AbstractMap.SimpleEntry<>(scenarioNumber, new Scenario()));
+        when(scenarioMapMock.entrySet()).thenReturn(entries);
+        presenter.refreshModelContent(scenarioMapMock);
+        verify(simulationMock, times(1)).replaceScenario(eq(scenarioIndex), any());
         assertEquals(scenarioSimulationModelMock, presenter.getModel());
         verify(scenarioSimulationViewMock, times(1)).refreshContent(eq(simulationMock));
         verify(statusMock, times(1)).setSimulation(eq(simulationMock));
+        verify(dataManagementStrategyMock, times(1)).setModel(eq(scenarioSimulationModelMock));
     }
 
     @Test
@@ -362,6 +386,25 @@ public class ScenarioSimulationEditorPresenterTest extends AbstractScenarioSimul
         assertFalse(presenter.isDirty());
     }
 
+    @Test
+    public void setRightPanel() {
+        presenter.setRightPanel(rightPanelPresenterMock);
+        verify(contextMock, times(1)).setRightPanelPresenter(rightPanelPresenterMock);
+        verify(rightPanelPresenterMock, times(1)).setEventBus(eventBusMock);
+        verify(dataManagementStrategyMock, times(1)).populateRightPanel(rightPanelPresenterMock, scenarioGridModelMock);
+        verify(rightPanelPresenterMock, times(1)).initCheatSheet(any());
+    }
+
+    @Test
+    public void getModelSuccessCallbackMethod() {
+        presenterSpy.getModelSuccessCallbackMethod(content);
+        verify(presenterSpy, times(1)).populateRightPanel();
+        verify(scenarioSimulationViewMock, times(1)).hideBusyIndicator();
+        verify(scenarioSimulationViewMock, times(1)).setContent(eq(content.getModel().getSimulation()));
+        verify(statusMock, times(1)).setSimulation(eq(content.getModel().getSimulation()));
+        verify(presenterSpy, times(1)).setOriginalHash(anyInt());
+    }
+
     private void onClosePlaceStatusOpen() {
         verify(versionRecordManagerMock, times(1)).clear();
         verify(scenarioGridPanelMock, times(1)).unregister();
