@@ -16,9 +16,7 @@
 
 package org.drools.workbench.screens.scenariosimulation.client.handlers;
 
-import java.util.ArrayList;
-import java.util.Collections;
-import java.util.List;
+import java.util.stream.IntStream;
 
 import com.ait.lienzo.client.core.event.NodeMouseClickEvent;
 import com.ait.lienzo.client.core.event.NodeMouseDoubleClickEvent;
@@ -33,14 +31,12 @@ import org.mockito.Mock;
 import org.uberfire.ext.wires.core.grids.client.model.GridCellEditAction;
 import org.uberfire.ext.wires.core.grids.client.model.GridColumn;
 import org.uberfire.ext.wires.core.grids.client.model.GridData;
-import org.uberfire.ext.wires.core.grids.client.widget.context.GridBodyCellEditContext;
 import org.uberfire.ext.wires.core.grids.client.widget.grid.renderers.grids.impl.BaseGridRendererHelper;
 
 import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertTrue;
 import static org.mockito.Matchers.any;
 import static org.mockito.Matchers.anyDouble;
-import static org.mockito.Matchers.anyInt;
 import static org.mockito.Matchers.eq;
 import static org.mockito.Mockito.doReturn;
 import static org.mockito.Mockito.mock;
@@ -79,6 +75,9 @@ public class ScenarioSimulationGridWidgetMouseEventHandlerTest extends AbstractS
     @Mock
     private BaseGridRendererHelper.RenderingBlockInformation renderingBlockInformation;
 
+    @Mock
+    private GridCellEditAction gridCellEditActionMock;
+
     private NodeMouseClickEvent clickEvent;
 
     private NodeMouseDoubleClickEvent doubleClickEvent;
@@ -103,62 +102,117 @@ public class ScenarioSimulationGridWidgetMouseEventHandlerTest extends AbstractS
         when(columnInformation.getColumn()).thenReturn((GridColumn) gridColumnMock);
         when(renderingInformation.getBodyBlockInformation()).thenReturn(renderingBlockInformation);
         when(renderingInformation.getFloatingBlockInformation()).thenReturn(renderingBlockInformation);
+        when(renderingInformation.getAllColumns()).thenReturn(columnsMock);
         when(informationHeaderMetaDataMock.getSupportedEditAction()).thenReturn(GridCellEditAction.SINGLE_CLICK);
         this.handler = spy(new ScenarioSimulationGridWidgetMouseEventHandler());
     }
 
     @Test
-    public void testHandleHeaderCell_NullColumn() {
+    public void handleHeaderCell_NullColumn() {
         when(columnInformation.getColumn()).thenReturn(null);
-        assertFalse(handler.handleHeaderCell(scenarioGridMock,
-                                            relativeLocation,
-                                            0,
-                                            0,
-                                            clickEvent));
+        commonHandleHeaderCell(true, true, 1, false, false);
     }
 
     @Test
     @SuppressWarnings("unchecked")
-    public void testHandleHeaderCell_NonEditableColumn() {
-        doReturn(false).when(handler).isEditableHeaderLocal(eq(gridColumnMock), anyInt());
-        assertTrue(handler.handleHeaderCell(scenarioGridMock,
-                                             relativeLocation,
-                                             0,
-                                             0,
-                                             clickEvent));
-        verify(informationHeaderMetaDataMock, never()).edit(any(GridBodyCellEditContext.class));
+    public void handleHeaderCell_NonEditableColumn() {
+        commonHandleHeaderCell(false, false, 1, false, true);
     }
 
     @Test
     @SuppressWarnings("unchecked")
-    public void testHandleHeaderCell_EditableColumn_NotEditableRow() {
-        doReturn(true).when(handler).isEditableHeaderLocal(eq(gridColumnMock), anyInt());
-        assertTrue(handler.handleHeaderCell(scenarioGridMock,
-                                             relativeLocation,
-                                             0,
-                                             0,
-                                             clickEvent));
-        verify(informationHeaderMetaDataMock, never()).edit(any(GridBodyCellEditContext.class));
+    public void handleHeaderCell_EditableColumn_NotStartEdit() {
+        commonHandleHeaderCell(true, false, 1, true, false);
     }
 
     @Test
     @SuppressWarnings("unchecked")
-    public void testHandleHeaderCell_EditableColumn_EditableRow_DoubleClickEvent() {
-        doReturn(true).when(handler).isEditableHeaderLocal(eq(gridColumnMock), anyInt());
-        when(gridColumnMock.getHeaderMetaData()).thenReturn(Collections.singletonList(informationHeaderMetaDataMock));
-        List<GridData.SelectedCell> selectedCellsMock = mock(ArrayList.class);
-        when(selectedCellsMock.size()).thenReturn(1);
-        when(informationHeaderMetaDataMock.getSupportedEditAction()).thenReturn(GridCellEditAction.DOUBLE_CLICK);
-        when(informationHeaderMetaDataMock.isInstanceHeader()).thenReturn(true);
-        when(scenarioGridModelMock.getSelectedHeaderCells()).thenReturn(selectedCellsMock);
-        when(gridColumnMock.isInstanceAssigned()).thenReturn(true);
-        when(gridColumnMock.isEditableHeaders()).thenReturn(true);
-        scenarioGridModelMock.selectHeaderCell(0, 0);
-        assertTrue(handler.handleHeaderCell(scenarioGridMock,
-                                             relativeLocation,
-                                             0,
-                                             0,
-                                             doubleClickEvent));
-        verify(informationHeaderMetaDataMock, times(1)).edit(any(GridBodyCellEditContext.class));
+    public void handleHeaderCell_EditableColumn_StartEdit() {
+        commonHandleHeaderCell(true, true, 1, true, true);
     }
+
+    @Test
+    @SuppressWarnings("unchecked")
+    public void handleHeaderCell_EditableColumn_WrongSelectedSize() {
+        commonHandleHeaderCell(true, true, 3, false, true);
+    }
+
+    @Test
+    @SuppressWarnings("unchecked")
+    public void handleBodyCell_NotEditSupportedLocal() {
+        commonHandleBodyCell(false, true, 1, false, false);
+    }
+
+    @Test
+    @SuppressWarnings("unchecked")
+    public void handleBodyCell_NotStartEditLocal() {
+        commonHandleBodyCell(true, false, 1, true, false);
+    }
+
+    @Test
+    @SuppressWarnings("unchecked")
+    public void handleBodyCell_StartEditLocal() {
+        commonHandleBodyCell(true, true, 1, true, true);
+    }
+
+    @Test
+    @SuppressWarnings("unchecked")
+    public void handleBodyCell_WrongSelectedSize() {
+        commonHandleBodyCell(true, true, 3, false, false);
+    }
+
+    private void commonHandleHeaderCell(boolean editSupportedLocal, boolean startEditLocal, int selectedHeaderCellsSize, boolean startEditLocalCalled, boolean expectedResult) {
+        int uiHeaderColumnIndex = 0;
+        int uiHeaderRowIndex = 0;
+        scenarioGridMock.getModel().getSelectedHeaderCells().clear();
+        IntStream.range(0, selectedHeaderCellsSize).forEach(i -> scenarioGridMock.getModel().getSelectedHeaderCells().add(mock(GridData.SelectedCell.class)));
+        doReturn(editSupportedLocal).when(handler).editSupportedLocal(any(), any());
+        doReturn(startEditLocal).when(handler).startEditLocal(eq(scenarioGridMock), eq(uiHeaderColumnIndex), eq(gridColumnMock), eq(uiHeaderRowIndex), eq(true));
+        if (expectedResult) {
+            assertTrue(handler.handleHeaderCell(scenarioGridMock,
+                                                relativeLocation,
+                                                uiHeaderRowIndex,
+                                                uiHeaderColumnIndex,
+                                                clickEvent));
+        } else {
+            assertFalse(handler.handleHeaderCell(scenarioGridMock,
+                                                 relativeLocation,
+                                                 uiHeaderRowIndex,
+                                                 uiHeaderColumnIndex,
+                                                 clickEvent));
+        }
+        if (startEditLocalCalled) {
+            verify(handler, times(1)).startEditLocal(eq(scenarioGridMock), eq(uiHeaderColumnIndex), eq(gridColumnMock), eq(uiHeaderRowIndex), eq(true));
+        } else {
+            verify(handler, never()).startEditLocal(eq(scenarioGridMock), eq(uiHeaderColumnIndex), eq(gridColumnMock), eq(uiHeaderRowIndex), eq(true));
+        }
+    }
+
+    private void commonHandleBodyCell(boolean editSupportedLocal, boolean startEditLocal, int selectedCellsSize, boolean startEditLocalCalled, boolean expectedResult) {
+        int uiHeaderColumnIndex = 0;
+        int uiHeaderRowIndex = 0;
+        scenarioGridMock.getModel().getSelectedCells().clear();
+        IntStream.range(0, selectedCellsSize).forEach(i -> scenarioGridMock.getModel().getSelectedCells().add(mock(GridData.SelectedCell.class)));
+        doReturn(editSupportedLocal).when(handler).editSupportedLocal(any(), any());
+        doReturn(startEditLocal).when(handler).startEditLocal(eq(scenarioGridMock), eq(uiHeaderColumnIndex), eq(gridColumnMock), eq(uiHeaderRowIndex), eq(false));
+        if (expectedResult) {
+            assertTrue(handler.handleBodyCell(scenarioGridMock,
+                                                relativeLocation,
+                                                uiHeaderRowIndex,
+                                                uiHeaderColumnIndex,
+                                                clickEvent));
+        } else {
+            assertFalse(handler.handleBodyCell(scenarioGridMock,
+                                                 relativeLocation,
+                                                 uiHeaderRowIndex,
+                                                 uiHeaderColumnIndex,
+                                                 clickEvent));
+        }
+        if (startEditLocalCalled) {
+            verify(handler, times(1)).startEditLocal(eq(scenarioGridMock), eq(uiHeaderColumnIndex), eq(gridColumnMock), eq(uiHeaderRowIndex), eq(false));
+        } else {
+            verify(handler, never()).startEditLocal(eq(scenarioGridMock), eq(uiHeaderColumnIndex), eq(gridColumnMock), eq(uiHeaderRowIndex), eq(false));
+        }
+    }
+
 }
